==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpltBinop.h <==
// public final class soot.jimple.parser.node.ACmpltBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eda7ad3814d40c74 soot_jimple_parser_node_ACmpltBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpltBinop_H_
#define _JC_soot_jimple_parser_node_ACmpltBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmplt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpltBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$refs	_jc_soot_jimple_parser_node_ACmpltBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpltBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$object	_jc_soot_jimple_parser_node_ACmpltBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vmethods	_jc_soot_jimple_parser_node_ACmpltBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vtable	_jc_soot_jimple_parser_node_ACmpltBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vtype	_jc_soot_jimple_parser_node_ACmpltBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$_init$b85eb0a7e0fbae71(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmplt$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$getCmplt$14cdadcdf5cda296(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$setCmplt$347f1e7fa9e65ccd(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$getCmplt$14cdadcdf5cda296;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$setCmplt$347f1e7fa9e65ccd;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpltBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmplt$object	*(*getCmplt$14cdadcdf5cda296)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmplt$347f1e7fa9e65ccd)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpltBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpltBinop$vmethods	soot_jimple_parser_node_ACmpltBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpltBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpltBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmplt$object	*__5fcmplt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpltBinop$refs {
    _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs	soot_jimple_parser_node_ACmpltBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpltBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs	soot_jimple_parser_node_ACmpltBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpltBinop$object {
	_jc_soot_jimple_parser_node_ACmpltBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpltBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpltBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpltBinop$vtype _jc_soot_jimple_parser_node_ACmpltBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpltBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpltBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpltBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpltBinop.h <==
// public final class soot.jimple.parser.node.ACmpltBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eda7ad3814d40c74 soot_jimple_parser_node_ACmpltBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpltBinop_H_
#define _JC_soot_jimple_parser_node_ACmpltBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmplt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpltBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$refs	_jc_soot_jimple_parser_node_ACmpltBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpltBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpltBinop$object	_jc_soot_jimple_parser_node_ACmpltBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vmethods	_jc_soot_jimple_parser_node_ACmpltBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vtable	_jc_soot_jimple_parser_node_ACmpltBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpltBinop$vtype	_jc_soot_jimple_parser_node_ACmpltBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$_init$b85eb0a7e0fbae71(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmplt$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$getCmplt$14cdadcdf5cda296(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpltBinop$method$setCmplt$347f1e7fa9e65ccd(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpltBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$getCmplt$14cdadcdf5cda296;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$setCmplt$347f1e7fa9e65ccd;
extern _jc_method _jc_soot_jimple_parser_node_ACmpltBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpltBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmplt$object	*(*getCmplt$14cdadcdf5cda296)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmplt$347f1e7fa9e65ccd)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *, struct _jc_soot_jimple_parser_node_TCmplt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpltBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpltBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpltBinop$vmethods	soot_jimple_parser_node_ACmpltBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpltBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpltBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmplt$object	*__5fcmplt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpltBinop$refs {
    _jc_soot_jimple_parser_node_ACmpltBinop$sub_refs	soot_jimple_parser_node_ACmpltBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpltBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpltBinop$sub_nonrefs	soot_jimple_parser_node_ACmpltBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpltBinop$object {
	_jc_soot_jimple_parser_node_ACmpltBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpltBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpltBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpltBinop$vtype _jc_soot_jimple_parser_node_ACmpltBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpltBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpltBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpltBinop_H_ */
